@@ -3,3 +3,6 @@ def multiply_2(x):
 
 def multiply_10(x):
     return x * 10
+
+def multiply_20(x):
+    return x * 20
